UReceiver

Struct UReceiver 

pub struct UReceiver<T> { /* private fields */ }
The receiving side of the unbounded queue.

Examples

use std::thread;
use std::time::Duration;

use omango::queue::spsc::unbounded;

let (tx, rx) = unbounded();

thread::spawn(move || {
    let _ = tx.send(1);
    thread::sleep(Duration::from_secs(1));
    let _ = tx.send(2);
});

assert_eq!(rx.recv(), Ok(1)); // Received immediately.
assert_eq!(rx.recv(), Ok(2)); // Received after 1 second.

Implementations

Source

impl<T: Send> UReceiver<T>

pub fn recv(&self) -> Result<T, RecvError>

Blocks the current thread until a message is received.

When the queue was closed, all receiving waiters will be woken up and return error.

Examples
use std::thread;
use std::time::Duration;

use omango::queue::spsc::unbounded;
use omango::error::RecvError;

let (tx, rx) = unbounded();

thread::spawn(move || {
    thread::sleep(Duration::from_secs(1));
    tx.send(5).unwrap();
    thread::sleep(Duration::from_secs(1));
    tx.close();
});

assert_eq!(rx.recv(), Ok(5));
assert_eq!(rx.recv(), Err(RecvError));
pub fn close(&self)

Fires closing queue notification.

After closed, all send operations will be failed.

Uses recv to read remaining messages.

Examples
use std::thread;
use std::time::Duration;

use omango::queue::spsc::unbounded;
use omango::error::{RecvError, SendError};

let (tx, rx) = unbounded();

thread::spawn(move || {
    assert_eq!(tx.send(1), Ok(()));
    tx.close();
});

thread::sleep(Duration::from_millis(500));
assert_eq!(rx.recv(), Ok(1));